@@ -1,10 +1,10 @@
 # !/usr/bin/env python3
 
-__version__="0.2.6"
+__version__="0.3.4"
 
 import argparse, json, os.path, urllib.request
 from rich.progress import Progress
-# rich (refined) ###########################################################################
+
 def get_file_size(url):
     with urllib.request.urlopen(url) as response:
         size = int(response.headers['Content-Length'])
@@ -30,7 +30,6 @@ def clone_file(url):
         print(f"File cloned successfully and saved as '{filename}'({format_size(file_size)}) in the current directory.")
     except Exception as e:
         print(f"Error: {e}")
-# ##########################################################################################
         
 def read_json_file(file_path):
     response = urllib.request.urlopen(file_path)
@@ -38,11 +37,9 @@ def read_json_file(file_path):
     # with open(file_path, 'r') as file:
         # data = json.load(file)
     return data
-
 def extract_names(data):
     for idx, entry in enumerate(data, start=1):
         print(f'{idx}. {entry["name"]}')
-
 def handle_user_input(data):
     while True:
         user_choice = input(f"Enter your choice (1 to {len(data)}) or 'q' to quit: ")
@@ -67,21 +64,24 @@ def __init__():
     # Subparser for 'clone [URL]' subcommand
     clone_parser = subparsers.add_parser('clone', help='download a GGUF file/model from URL')
     clone_parser.add_argument('url', type=str, help='URL to download from (i.e., cgg clone [url])')
-    # Subparser for 'menu/cpp/c/gpp/g/s/r/us' subcommand
+    # Subparser for 'menu/cpp/c/gpp/g/s/r/us...etc.' subcommand
     subparsers.add_parser('menu', help='connector selection list:')
     subparsers.add_parser('cpp', help='cpp connector')
     subparsers.add_parser('gpp', help='gpp connector')
     subparsers.add_parser('c', help='c connector')
     subparsers.add_parser('g', help='g connector')
     subparsers.add_parser('r', help='metadata reader')
+    subparsers.add_parser('a', help='model analyzor')
     subparsers.add_parser('s', help='sample GGUF list (internet required)')
     subparsers.add_parser('pc', help='pdf analyzor c')
     subparsers.add_parser('pp', help='pdf analyzor p')
+    subparsers.add_parser('oc', help='wav recognizor c (internet required)')
+    subparsers.add_parser('op', help='wav recognizor p (internet required)')
     subparsers.add_parser('vc', help='wav recognizor c')
     subparsers.add_parser('vp', help='wav recognizor p')
+    subparsers.add_parser('io', help='launch to gguf.io (mirror of us)')
     subparsers.add_parser('us', help='launch to gguf.us')
     args = parser.parse_args()
-    # if statement below
     if args.subcommand == 'clone':
         clone_file(args.url)
     elif args.subcommand == 's':
@@ -93,8 +93,16 @@ def __init__():
         handle_user_input(json_data)
     elif args.subcommand == 'us':
         from gguf_connector import w
+    elif args.subcommand == 'io':
+        from gguf_connector import i
     elif args.subcommand == 'r':
         from gguf_connector import r
+    elif args.subcommand == 'a':
+        from gguf_connector import r2
+    elif args.subcommand == 'oc':
+        from gguf_connector import cg
+    elif args.subcommand == 'op':
+        from gguf_connector import pg
     elif args.subcommand == 'vc':
         from gguf_connector import cs
     elif args.subcommand == 'vp':
